django\_opt\_out\.tests package
===============================

Submodules
----------

django\_opt\_out\.tests\.settings module
----------------------------------------

.. automodule:: django_opt_out.tests.settings
    :members:
    :undoc-members:
    :show-inheritance:

django\_opt\_out\.tests\.test\_cli module
-----------------------------------------

.. automodule:: django_opt_out.tests.test_cli
    :members:
    :undoc-members:
    :show-inheritance:

django\_opt\_out\.tests\.test\_forms module
-------------------------------------------

.. automodule:: django_opt_out.tests.test_forms
    :members:
    :undoc-members:
    :show-inheritance:

django\_opt\_out\.tests\.test\_models module
--------------------------------------------

.. automodule:: django_opt_out.tests.test_models
    :members:
    :undoc-members:
    :show-inheritance:

django\_opt\_out\.tests\.test\_views module
-------------------------------------------

.. automodule:: django_opt_out.tests.test_views
    :members:
    :undoc-members:
    :show-inheritance:

django\_opt\_out\.tests\.urls module
------------------------------------

.. automodule:: django_opt_out.tests.urls
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: django_opt_out.tests
    :members:
    :undoc-members:
    :show-inheritance:
